==> haskell-hslua-objectorientation-2.3.0-44-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-objectorientation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-objectorientation
version:              2.3.0
visibility:           public
id:                   hslua-objectorientation-2.3.0-IoRlW1ihdnX99EzIUKBTrz
key:                  hslua-objectorientation-2.3.0-IoRlW1ihdnX99EzIUKBTrz
license:              MIT
copyright:            © 2021-2023 Albert Krewinkel
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Object orientation tools for HsLua
description:
    Expose Haskell objects to Lua with an object oriented
    interface.

category:             Foreign
abi:                  2c73064a77b83577a7480c03eb860775
exposed:              True
exposed-modules:
    HsLua.ObjectOrientation HsLua.ObjectOrientation.Operation

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hslua-objectorientation-2.3.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hslua-objectorientation-2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-objectorientation
hs-libraries:         HShslua-objectorientation-2.3.0-IoRlW1ihdnX99EzIUKBTrz
depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    exceptions-0.10.4 hslua-core-2.3.1-IyI9OufFuBtHH3ZMlxCaYs
    hslua-marshalling-2.3.0-Ig2P4Cxc1BcAg3kht9VCbg
    hslua-typing-0.1.1-IaBCOH7PMF4LZo4fgmC6wY mtl-2.2.2 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-hslua-objectorientation/html/hslua-objectorientation.haddock

haddock-html:         /usr/share/doc/haskell-hslua-objectorientation/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-objectorientation-2.3.0-56.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-objectorientation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-objectorientation
version:              2.3.0
visibility:           public
id:                   hslua-objectorientation-2.3.0-BJJhygzUKjM8RHGcfP1VqB
key:                  hslua-objectorientation-2.3.0-BJJhygzUKjM8RHGcfP1VqB
license:              MIT
copyright:            © 2021-2023 Albert Krewinkel
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Object orientation tools for HsLua
description:
    Expose Haskell objects to Lua with an object oriented
    interface.

category:             Foreign
abi:                  f1c93e68f69c21e240b632cf3b12ec93
exposed:              True
exposed-modules:
    HsLua.ObjectOrientation HsLua.ObjectOrientation.Operation

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hslua-objectorientation-2.3.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hslua-objectorientation-2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-objectorientation
hs-libraries:         HShslua-objectorientation-2.3.0-BJJhygzUKjM8RHGcfP1VqB
depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    exceptions-0.10.4 hslua-core-2.3.1-8C0aoFQaOrXKTRw02glTvW
    hslua-marshalling-2.3.1-KsyI9r2uX5jHis6xOiGZDK
    hslua-typing-0.1.1-5rTCXzJgupP5HDFshZa90l mtl-2.2.2 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-hslua-objectorientation/html/hslua-objectorientation.haddock

haddock-html:         /usr/share/doc/haskell-hslua-objectorientation/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
